@@ -22,10 +22,9 @@
 #' you can provide a list with the names \code{'continuous'}, \code{'proportion'}, \code{'factor'} and
 #' the function will choose accordingly. If you fail to define a certain category
 #' it will default to the above.
-#' 
-#' You can also use a custom function that returns a string with the attribute 'colname' set that will be appended
-#' to the results instead of the p-value column.
-#' to the results instead of the p-value column.
+#'
+#' You can also use a custom function that returns a string with the attribute \code{'colname'}
+#' set that will be appended to the results instead of the p-value column.
 #'
 #' @param x The variable that you want the statistics for
 #' @param by The variable that you want to split into different
@@ -116,7 +115,7 @@ getDescriptionStatsBy <- function(x,
                                   statistics = FALSE,
                                   statistics.sig_lim = 10^-4,
                                   statistics.two_dec_lim = 10^-2,
-                                  statistics.suppress_warnings =TRUE,
+                                  statistics.suppress_warnings = TRUE,
                                   useNA = c("ifany", "no", "always"),
                                   useNA.digits = digits,
                                   continuous_fn = describeMean,
@@ -133,28 +132,33 @@ getDescriptionStatsBy <- function(x,
                                   header_count,
                                   missing_value = "-",
                                   names_of_missing = NULL,
-                                  ...){
-
+                                  ...) {
   API_changes <-
-    c(show_missing_digits = "show_missing.digits",
+    c(
+      show_missing_digits = "show_missing.digits",
       show_missing = "useNA",
       sig.limit = "statistics.sig_lim",
-      two_dec.limit = "statistics.two_dec_lim")
+      two_dec.limit = "statistics.two_dec_lim"
+    )
   dots <- list(...)
   fenv <- environment()
-  for (i in 1:length(API_changes)){
+  for (i in 1:length(API_changes)) {
     old_name <- names(API_changes)[i]
     new_name <- API_changes[i]
-    if (old_name %in% names(dots)){
-      if ("name" %in% class(fenv[[new_name]])){
+    if (old_name %in% names(dots)) {
+      if ("name" %in% class(fenv[[new_name]])) {
         fenv[[new_name]] <- dots[[old_name]]
         dots[[old_name]] <- NULL
-        warning("Deprecated: '", old_name, "'",
-                " argument is now '", new_name ,"'",
-                " as of ver. 1.0")
-      }else{
-        stop("You have set both the old parameter name: '", old_name, "'",
-             " and the new parameter name: '", new_name, "'.")
+        warning(
+          "Deprecated: '", old_name, "'",
+          " argument is now '", new_name, "'",
+          " as of ver. 1.0"
+        )
+      } else {
+        stop(
+          "You have set both the old parameter name: '", old_name, "'",
+          " and the new parameter name: '", new_name, "'."
+        )
       }
     }
   }
@@ -162,7 +166,7 @@ getDescriptionStatsBy <- function(x,
   useNA <- match.arg(useNA)
   if (!is.na(digits.nonzero)) {
     if (!is.numeric(digits.nonzero)
-        || floor(digits.nonzero) != digits.nonzero
+    || floor(digits.nonzero) != digits.nonzero
     ) {
       stop("The digits.nonzero should be an integer, you provided: ", digits.nonzero)
     }
@@ -170,91 +174,109 @@ getDescriptionStatsBy <- function(x,
       stop("The digits.nonzero must be smaller than digits")
     }
   }
-  
-  if (!is.function(statistics)){
+
+  if (!is.function(statistics)) {
     if (is.list(statistics) ||
-        (statistics != FALSE)){
-        if (is.list(statistics)){
-          types <- c("continuous",
-                     "proportion",
-                     "factor")
-          if (any(!names(statistics) %in% types))
-            stop("If you want to provide custom functions for generating statistics",
-                 " you must either provide a function or a list with the elements:",
-                 " '", paste(types, collapse="', '"), "'")
-          
-          if (is.numeric(x) &&
-              length(unique(x)) != 2){
-            statistics <- statistics[["continuous"]]
-          }else if (length(unique(x)) == 2){
-            if ("proportion" %in% names(statistics)){
-              statistics <- statistics[["proportion"]]
-            }else{
-              statistics <- statistics[["factor"]]
-            }
-          }else{
+      (statistics != FALSE)) {
+      if (is.list(statistics)) {
+        types <- c(
+          "continuous",
+          "proportion",
+          "factor"
+        )
+        if (any(!names(statistics) %in% types)) {
+          stop(
+            "If you want to provide custom functions for generating statistics",
+            " you must either provide a function or a list with the elements:",
+            " '", paste(types, collapse = "', '"), "'"
+          )
+        }
+
+        if (is.numeric(x) &&
+          length(unique(x)) != 2) {
+          statistics <- statistics[["continuous"]]
+        } else if (length(unique(x)) == 2) {
+          if ("proportion" %in% names(statistics)) {
+            statistics <- statistics[["proportion"]]
+          } else {
             statistics <- statistics[["factor"]]
           }
-          
-          if (is.character(statistics))
-            statistics <- get(statistics)
+        } else {
+          statistics <- statistics[["factor"]]
         }
-        
-        if (!is.function(statistics)){
-          if(length(unique(x)) == 2){
-            statistics <- getPvalFisher
-          }else if(is.numeric(x)){
-            if (length(unique(by)) == 2)
-              statistics <- getPvalWilcox
-            else
-              statistics <- getPvalAnova
-          }else{
-            statistics <- getPvalFisher
-          }
+
+        if (is.character(statistics)) {
+          statistics <- get(statistics)
         }
       }
+
+      if (!is.function(statistics)) {
+        if (length(unique(x)) == 2) {
+          statistics <- getPvalFisher
+        } else if (is.numeric(x)) {
+          if (length(unique(by)) == 2) {
+            statistics <- getPvalWilcox
+          } else {
+            statistics <- getPvalAnova
+          }
+        } else {
+          statistics <- getPvalFisher
+        }
+      }
+    }
   }
-  
-  if (is.function(statistics)){
-    if (statistics.suppress_warnings){
+
+  if (is.function(statistics)) {
+    if (statistics.suppress_warnings) {
       pval <- suppressWarnings(
-        statistics(x = x,
-                   by = by)
+        statistics(
+          x = x,
+          by = by
+        )
       )
-    }else{
-      pval <- 
-        statistics(x = x,
-                   by = by)
+    } else {
+      pval <-
+        statistics(
+          x = x,
+          by = by
+        )
     }
   }
 
   # Always have a total column if the description statistics
   # are presented in a horizontal fashion
   if (missing(add_total_col) &&
-        hrzl_prop){
-    add_total_col = TRUE
+    hrzl_prop) {
+    add_total_col <- TRUE
   }
 
-  if(is.null(x))
-    stop("You haven't provided an x-value to do the statistics by.",
-         " This error is most frequently caused by referencing an old",
-         " variable name that doesn't exist anymore")
-  if(is.null(by))
-    stop("You haven't provided a by-value to do the statistics by.",
-         " This error is most frequently caused by referencing an old",
-         " variable name that doesn't exist anymore")
+  if (is.null(x)) {
+    stop(
+      "You haven't provided an x-value to do the statistics by.",
+      " This error is most frequently caused by referencing an old",
+      " variable name that doesn't exist anymore"
+    )
+  }
+  if (is.null(by)) {
+    stop(
+      "You haven't provided a by-value to do the statistics by.",
+      " This error is most frequently caused by referencing an old",
+      " variable name that doesn't exist anymore"
+    )
+  }
 
   # If there is a label for the variable
   # that one should be used otherwise go
   # with the name of the variable
-  if (label(x) == "")
+  if (label(x) == "") {
     name <- paste0(deparse(substitute(x)), collapse = "")
-  else
+  } else {
     name <- label(x)
+  }
 
   if (is.logical(x)) {
-    x <- factor(x, levels=c(TRUE, FALSE))
-  } else if (is.character(x) && any(table(x,by) == 0)) {
+    x <- factor(x, levels = c(TRUE, FALSE))
+  } else if (is.character(x) && any(table(x, by) == 0)) {
     x <- factor(x)
   }
 
@@ -262,32 +284,36 @@ getDescriptionStatsBy <- function(x,
   # Send a warning, since the user might be unaware of this
   # potentially disturbing fact. The dataset should perhaps by
   # subsetted by is.na(by) == FALSE
-  if (any(is.na(by))){
-    warning(sprintf("Your 'by' variable has %d missing values", sum(is.na(by))),
-            "\n   The corresponding 'x' and 'by' variables are automatically removed")
+  if (any(is.na(by))) {
+    warning(
+      sprintf("Your 'by' variable has %d missing values", sum(is.na(by))),
+      "\n   The corresponding 'x' and 'by' variables are automatically removed"
+    )
     x <- x[!is.na(by)]
-    if (inherits(x, "factor")){
+    if (inherits(x, "factor")) {
       x <- factor(x)
     }
     by <- by[!is.na(by)]
-    if (inherits(by, "factor")){
+    if (inherits(by, "factor")) {
       by <- factor(by)
     }
   }
 
   if (useNA == "ifany" &&
-        any(is.na(x)))
+    any(is.na(x))) {
     useNA <- "always"
+  }
 
   # If all values are to be shown then simply use
   # the factors function, provided describeProp was specified
-  if (show_all_values & deparse(substitute(prop_fn)) == "describeProp")
+  if (show_all_values & deparse(substitute(prop_fn)) == "describeProp") {
     prop_fn <- describeFactors
+  }
 
-  addEmptyValuesToMakeListCompatibleWithMatrix <- function(t){
+  addEmptyValuesToMakeListCompatibleWithMatrix <- function(t) {
     # Convert the list into a list with vectors instead of matrices
-    for (n in names(t)){
-      if (is.matrix(t[[n]])){
+    for (n in names(t)) {
+      if (is.matrix(t[[n]])) {
         tmp_names <- rownames(t[[n]])
         t[[n]] <- as.vector(t[[n]])
         names(t[[n]]) <- tmp_names
@@ -298,31 +324,33 @@ getDescriptionStatsBy <- function(x,
     # the factored variable. This could potentially be
     # a problem although probably more theoretical
     all_row_names <- c()
-    for (n in names(t)){
+    for (n in names(t)) {
       all_row_names <- union(all_row_names, names(t[[n]]))
     }
 
     # No rownames exist, this occurs often
     # when there is only one row and that row doesn't
     # have a name
-    if (is.null(all_row_names))
+    if (is.null(all_row_names)) {
       return(t)
+    }
 
     # The missing NA element should always be last
-    if (any(is.na(all_row_names)))
+    if (any(is.na(all_row_names))) {
       all_row_names <- append(all_row_names[is.na(all_row_names) == FALSE], NA)
+    }
 
     ret <- list()
-    for (n in names(t)){
+    for (n in names(t)) {
       # Create an empty array
-      ret[[n]] <- rep(missing_value, times=length(all_row_names))
+      ret[[n]] <- rep(missing_value, times = length(all_row_names))
       names(ret[[n]]) <- all_row_names
       # Loop and add all the values
-      for (nn in all_row_names){
-        if (nn %in% names(t[[n]])){
-          if (is.na(nn)){
+      for (nn in all_row_names) {
+        if (nn %in% names(t[[n]])) {
+          if (is.na(nn)) {
             ret[[n]][is.na(names(ret[[n]]))] <- t[[n]][is.na(names(t[[n]]))]
-          }else{
+          } else {
             ret[[n]][nn] <- t[[n]][nn]
           }
         }
@@ -332,26 +360,31 @@ getDescriptionStatsBy <- function(x,
     return(ret)
   }
 
-  if (is.numeric(x)){
+  if (is.numeric(x)) {
     # If the numeric has horizontal_proportions then it's only so in the
     # missing category
-    if (hrzl_prop)
-      t <- by(x, by, FUN=continuous_fn, html=html, 
-              digits=digits,
-              digits.nonzero=digits.nonzero,              
-              number_first=numbers_first,
-              useNA = useNA,
-              useNA.digits = useNA.digits,
-              horizontal_proportions = table(is.na(x), useNA=useNA),
-              percentage_sign = percentage_sign)
-    else
-      t <- by(x, by, FUN=continuous_fn, html=html, 
-              digits=digits,
-              digits.nonzero=digits.nonzero,              
-              number_first=numbers_first,
-              useNA = useNA,
-              useNA.digits = useNA.digits,
-              percentage_sign = percentage_sign)
+    if (hrzl_prop) {
+      t <- by(x, by,
+        FUN = continuous_fn, html = html,
+        digits = digits,
+        digits.nonzero = digits.nonzero,
+        number_first = numbers_first,
+        useNA = useNA,
+        useNA.digits = useNA.digits,
+        horizontal_proportions = table(is.na(x), useNA = useNA),
+        percentage_sign = percentage_sign
+      )
+    } else {
+      t <- by(x, by,
+        FUN = continuous_fn, html = html,
+        digits = digits,
+        digits.nonzero = digits.nonzero,
+        number_first = numbers_first,
+        useNA = useNA,
+        useNA.digits = useNA.digits,
+        percentage_sign = percentage_sign
+      )
+    }
 
     missing_t <- sapply(t, is.null)
     if (any(missing_t)) {
@@ -361,7 +394,7 @@ getDescriptionStatsBy <- function(x,
         t[missing_t][[i]] <- substitute_t
       }
     }
-    
+
     if (all(unlist(sapply(t, is.na))) & !is.null(names_of_missing)) {
       substitute_t <- rep(missing_value, length(names_of_missing))
       names(substitute_t) <- names_of_missing
@@ -373,32 +406,32 @@ getDescriptionStatsBy <- function(x,
       t <- substitute_list
     }
 
-    if (length(t[[1]]) != 1){
+    if (length(t[[1]]) != 1) {
       fn_name <- deparse(substitute(continuous_fn))
-      if (fn_name == "describeMean")
-        names(t[[1]][1]) = "Mean"
-      else if (fn_name == "describeMedian")
-        names(t[[1]][1]) = "Median"
-      else
-        names(t[[1]][1]) = fn_name
+      if (fn_name == "describeMean") {
+        names(t[[1]][1]) <- "Mean"
+      } else if (fn_name == "describeMedian") {
+        names(t[[1]][1]) <- "Median"
+      } else {
+        names(t[[1]][1]) <- fn_name
+      }
     }
-
-
-  }else if((!is.factor(x) &&
-              length(unique(na.omit(x))) == 2) ||
-             (is.factor(x) &&
-                length(levels(x)) == 2) &&
-             hrzl_prop == FALSE){
-
+  } else if ((!is.factor(x) &&
+    length(unique(na.omit(x))) == 2) ||
+    (is.factor(x) &&
+      length(levels(x)) == 2) &&
+      hrzl_prop == FALSE) {
     default_ref <- prDescGetAndValidateDefaultRef(x, default_ref)
 
-    t <- by(x, by, FUN=prop_fn, html=html, 
-            digits=digits,
-            digits.nonzero=digits.nonzero,              
-            number_first=numbers_first,
-            useNA = useNA,
-            useNA.digits = useNA.digits,
-            default_ref = default_ref, percentage_sign = percentage_sign)
+    t <- by(x, by,
+      FUN = prop_fn, html = html,
+      digits = digits,
+      digits.nonzero = digits.nonzero,
+      number_first = numbers_first,
+      useNA = useNA,
+      useNA.digits = useNA.digits,
+      default_ref = default_ref, percentage_sign = percentage_sign
+    )
 
     missing_t <- sapply(t, is.null)
     if (any(missing_t)) {
@@ -419,15 +452,18 @@ getDescriptionStatsBy <- function(x,
       }
       t <- substitute_list
     }
-    
+
     # Check that we're dealing with only one row
-    if (unique(sapply(t, length)) == 1)
+    if (unique(sapply(t, length)) == 1) {
       # Set the rowname to a special format
       # if there was missing and this is an matrix
       # then we should avoid using this format
-      name <- sprintf("%s %s",
-                      capitalize(levels(x)[default_ref]),
-                      tolower(name))
+      name <- sprintf(
+        "%s %s",
+        capitalize(levels(x)[default_ref]),
+        tolower(name)
+      )
+    }
 
     if (NEJMstyle) {
       # LaTeX needs an escape before %
@@ -436,37 +472,41 @@ getDescriptionStatsBy <- function(x,
       # html (markdown)
       percent_sign <- ifelse(html, "%", "\\%")
 
-      if (numbers_first)
+      if (numbers_first) {
         name <- sprintf("%s - no (%s)", name, percent_sign)
-      else
+      } else {
         name <- sprintf("%s - %s (no)", name, percent_sign)
+      }
     }
 
     # If this is the only row then set that row to the current name
-    if (length(t[[1]]) == 1){
+    if (length(t[[1]]) == 1) {
       names(t[[1]][1]) <- name
     }
-
-  }else{
+  } else {
     # Make sure that the total isn't using proportions (happens with hrzl_prop)
     prop_fn <- factor_fn
-    if (hrzl_prop){
-      t <- by(x, by, FUN=factor_fn, html=html,
-              digits=digits,
-              digits.nonzero=digits.nonzero,              
-              number_first=numbers_first,
-              useNA = useNA,
-              useNA.digits = useNA.digits,
-              horizontal_proportions = table(x, useNA=useNA),
-              percentage_sign = percentage_sign)
-    }else{
-      t <- by(x, by, FUN=factor_fn, html=html,
-              digits=digits,
-              digits.nonzero=digits.nonzero,              
-              number_first=numbers_first,
-              useNA = useNA,
-              useNA.digits = useNA.digits,
-              percentage_sign = percentage_sign)
+    if (hrzl_prop) {
+      t <- by(x, by,
+        FUN = factor_fn, html = html,
+        digits = digits,
+        digits.nonzero = digits.nonzero,
+        number_first = numbers_first,
+        useNA = useNA,
+        useNA.digits = useNA.digits,
+        horizontal_proportions = table(x, useNA = useNA),
+        percentage_sign = percentage_sign
+      )
+    } else {
+      t <- by(x, by,
+        FUN = factor_fn, html = html,
+        digits = digits,
+        digits.nonzero = digits.nonzero,
+        number_first = numbers_first,
+        useNA = useNA,
+        useNA.digits = useNA.digits,
+        percentage_sign = percentage_sign
+      )
     }
     missing_t <- sapply(t, is.null)
     if (any(missing_t)) {
@@ -476,7 +516,7 @@ getDescriptionStatsBy <- function(x,
         t[missing_t][[i]] <- substitute_t
       }
     }
-    
+
     if (all(unlist(sapply(t, is.na))) & !is.null(names_of_missing)) {
       substitute_t <- rep(missing_value, length(names_of_missing))
       names(substitute_t) <- names_of_missing
@@ -492,120 +532,135 @@ getDescriptionStatsBy <- function(x,
   # Convert the list into a matrix compatible format
   t <- addEmptyValuesToMakeListCompatibleWithMatrix(t)
   # Convert into a matrix
-  results <- matrix(unlist(t), ncol=length(t))
+  results <- matrix(unlist(t), ncol = length(t))
 
 
-  getHeader <- function (tbl_cnt, header_count, html) {
+  getHeader <- function(tbl_cnt, header_count, html) {
     if (missing(header_count) ||
-          identical(header_count, FALSE)){
+      identical(header_count, FALSE)) {
       return(names(tbl_cnt))
     }
 
-    if (is.character(header_count)){
-      if (!grepl("%s", header_count, fixed = TRUE))
-        stop("Your header_count must accept a string character",
-             " or it will fail to add the count, i.e. use the ",
-             " format: 'Text before %s text after'")
+    if (is.character(header_count)) {
+      if (!grepl("%s", header_count, fixed = TRUE)) {
+        stop(
+          "Your header_count must accept a string character",
+          " or it will fail to add the count, i.e. use the ",
+          " format: 'Text before %s text after'"
+        )
+      }
       cnt_str <-
-        sprintf(header_count,
-                txtInt(tbl_cnt))
-
-    }else{
+        sprintf(
+          header_count,
+          txtInt(tbl_cnt)
+        )
+    } else {
       cnt_str <- paste("No.", txtInt(tbl_cnt))
     }
 
     return(mapply(txtMergeLines,
-                  names(tbl_cnt),
-                  cnt_str,
-                  html=html))
+      names(tbl_cnt),
+      cnt_str,
+      html = html
+    ))
   }
 
   cn <- getHeader(table(by), header_count, html)
 
 
   # Add the proper rownames
-  if ("matrix" %in% class(t[[1]]))
+  if ("matrix" %in% class(t[[1]])) {
     rownames(results) <- rownames(t[[1]])
-  else
+  } else {
     rownames(results) <- names(t[[1]])
+  }
 
   # This is an effect from the numeric variable not having
   # a naming function
-  if (is.null(rownames(results)) && nrow(results) == 1)
+  if (is.null(rownames(results)) && nrow(results) == 1) {
     rownames(results) <- name
+  }
 
   if (!missing(add_total_col) &&
-        add_total_col != FALSE){
+    add_total_col != FALSE) {
     total_table <- prGetStatistics(x[is.na(by) == FALSE],
-                                   numbers_first=numbers_first,
-                                   show_perc=total_col_show_perc,
-                                   show_all_values = show_all_values,
-                                   useNA=useNA,
-                                   useNA.digits = useNA.digits,
-                                   html=html,
-                                   digits=digits,
-                                   continuous_fn = continuous_fn,
-                                   factor_fn = factor_fn,
-                                   prop_fn = prop_fn,
-                                   percentage_sign = percentage_sign)
+      numbers_first = numbers_first,
+      show_perc = total_col_show_perc,
+      show_all_values = show_all_values,
+      useNA = useNA,
+      useNA.digits = useNA.digits,
+      html = html,
+      digits = digits,
+      continuous_fn = continuous_fn,
+      factor_fn = factor_fn,
+      prop_fn = prop_fn,
+      percentage_sign = percentage_sign
+    )
 
-    if (!is.matrix(total_table)){
-      total_table <- matrix(total_table, ncol=1, dimnames=list(names(total_table)))
+    if (!is.matrix(total_table)) {
+      total_table <- matrix(total_table, ncol = 1, dimnames = list(names(total_table)))
     }
 
-    if (nrow(total_table) != nrow(results)){
-      stop("There is a discrepancy in the number of rows in the total table",
-           " and the by results: ", nrow(total_table), " total vs ", nrow(results), " results",
-           "\n Rows total:", paste(rownames(total_table), collapse=", "),
-           "\n Rows results:", paste(rownames(results), collapse=", "))
+    if (nrow(total_table) != nrow(results)) {
+      stop(
+        "There is a discrepancy in the number of rows in the total table",
+        " and the by results: ", nrow(total_table), " total vs ", nrow(results), " results",
+        "\n Rows total:", paste(rownames(total_table), collapse = ", "),
+        "\n Rows results:", paste(rownames(results), collapse = ", ")
+      )
     }
 
-    cn_tot <- getHeader(c(Total=length(x[is.na(by) == FALSE])),
-                        header_count, html)
-    if (add_total_col != "last"){
+    cn_tot <- getHeader(
+      c(Total = length(x[is.na(by) == FALSE])),
+      header_count, html
+    )
+    if (add_total_col != "last") {
       results <- cbind(total_table, results)
       cn <- c(cn_tot, cn)
-    }else{
+    } else {
       results <- cbind(results, total_table)
       cn <- c(cn, cn_tot)
     }
   }
 
-  if (isTRUE(use_units)){
-    if (units(x) != ""){
-      unitcol <- rep(sprintf("%s",units(x)), times=NROW(results))
+  if (isTRUE(use_units)) {
+    if (units(x) != "") {
+      unitcol <- rep(sprintf("%s", units(x)), times = NROW(results))
       unitcol[rownames(results) == "Missing"] <- ""
-    }else{
-      unitcol <- rep("", times=NROW(results))
+    } else {
+      unitcol <- rep("", times = NROW(results))
     }
-    if (length(unitcol) != nrow(results)){
-      stop("There is an discrepancy in the number of rows in the units",
-           " and the by results: ", length(unitcol), " units vs ", nrow(results), " results",
-           "\n Units:", paste(unitcol, collapse=", "),
-           "\n Rows results:", paste(rownames(results), collapse=", "))
+    if (length(unitcol) != nrow(results)) {
+      stop(
+        "There is an discrepancy in the number of rows in the units",
+        " and the by results: ", length(unitcol), " units vs ", nrow(results), " results",
+        "\n Units:", paste(unitcol, collapse = ", "),
+        "\n Rows results:", paste(rownames(results), collapse = ", ")
+      )
     }
     results <- cbind(results, unitcol)
     cn <- c(cn, "units")
-  }else if(use_units == "name"){
-    if (units(x) != ""){
+  } else if (use_units == "name") {
+    if (units(x) != "") {
       name <- sprintf("%s (%s)", name, units(x))
     }
   }
 
-  if (is.function(statistics)){
+  if (is.function(statistics)) {
     if (is.numeric(pval) &&
-        pval <= 1 &&
-        pval >= 0){
+      pval <= 1 &&
+      pval >= 0) {
       pval <- txtPval(pval,
-                      lim.sig =statistics.sig_lim,
-                      lim.2dec = statistics.two_dec_lim,
-                      html = html)
-      results <- cbind(results, c(pval, rep("", nrow(results)-1)))
+        lim.sig = statistics.sig_lim,
+        lim.2dec = statistics.two_dec_lim,
+        html = html
+      )
+      results <- cbind(results, c(pval, rep("", nrow(results) - 1)))
       cn <- c(cn, "P-value")
-    }else if(is.character(pval) && !is.null(attr(pval, 'colname'))){
-      results <- cbind(results, c(pval, rep("", nrow(results)-1)))
-      cn <- c(cn, attr(pval, 'colname'))
-    }else{
+    } else if (is.character(pval) && !is.null(attr(pval, "colname"))) {
+      results <- cbind(results, c(pval, rep("", nrow(results) - 1)))
+      cn <- c(cn, attr(pval, "colname"))
+    } else {
       stop("Your statistics function should either return a numerical value from 0 to 1 or a character with the attribute 'colname'")
     }
   }
@@ -617,5 +672,5 @@ getDescriptionStatsBy <- function(x,
   # not be used later on
   label(results) <- name
 
-  return (results)
+  return(results)
 }
